pub struct SBox<T>where
T: HasSchema,{ /* private fields */ }Expand description
A typed version of SchemaBox.
This allows to use SBox<T> extremely similar to a Box<T> except that it can be converted
to and from a SchemaBox for compatibility with the schema ecosystem.
Also, compared to a SchemaBox, it is more efficient to access, because it avoids extra
runtime checks for a matching schema after it has been created, and doesn’t need to be cast to
T upon every access.
Implementations